@@ -7,15 +7,15 @@
 # 
 #   The GNU General Public License, Version 3, June 2007
 # 
-package Games::Pandemic::Tk::Dialog;
-our $VERSION = '0.6.0';
-
-# ABSTRACT: base class for Games::Pandemic dialog windows
-
 use 5.010;
 use strict;
 use warnings;
 
+package Games::Pandemic::Tk::Dialog;
+our $VERSION = '0.7.0';
+
+# ABSTRACT: base class for Games::Pandemic dialog windows
+
 use Moose;
 use MooseX::AttributeHelpers;
 use MooseX::SemiAffordanceAccessor;
@@ -27,12 +27,13 @@ use Games::Pandemic::Tk::Utils;
 
 # -- accessors
 
-has parent => ( is=>'ro', required=>1, weak_ref=>1, isa=>'Tk::Widget' );
-has title  => ( is=>'rw', isa=>'Str', lazy_build=>1 );
-has header => ( is=>'rw', isa=>'Str', lazy_build=>1 );
+has parent    => ( is=>'ro', isa=>'Tk::Widget', required=>1, weak_ref=>1, );
+has title     => ( is=>'ro', isa=>'Str',  lazy_build=>1 );
+has header    => ( is=>'ro', isa=>'Str',  lazy_build=>1 );
+has resizable => ( is=>'ro', isa=>'Bool', lazy_build=>1 );
 has _toplevel => ( is=>'rw', isa=>'Tk::Toplevel' );
-has _ok     => ( is=>'ro', isa=>'Str', lazy_build=>1 );
-has _cancel => ( is=>'ro', isa=>'Str', lazy_build=>1 );
+has _ok       => ( is=>'ro', isa=>'Str', lazy_build=>1 );
+has _cancel   => ( is=>'ro', isa=>'Str', lazy_build=>1 );
 
 
 # a hash to store the widgets for easier reference.
@@ -71,10 +72,11 @@ sub DEMOLISH {
 }
 
 # lazy builders
-sub _build_title   { T('Pandemic') }
-sub _build_header  { '' }
-sub _build__ok     { '' }
-sub _build__cancel { '' }
+sub _build_title     { T('Pandemic') }
+sub _build_header    { '' }
+sub _build_resizable { 0 }
+sub _build__ok       { '' }
+sub _build__cancel   { '' }
 
 
 # -- gui methods
@@ -148,7 +150,11 @@ sub _build_gui {
 
     # center window & make it appear
     $top->Popup( -popover => $parent );
-    $top->resizable(0,0);
+    if ( $self->resizable ) {
+        $top->minsize($top->width, $top->height);
+    } else {
+        $top->resizable(0,0);
+    }
 }
 
 
@@ -168,7 +174,7 @@ Games::Pandemic::Tk::Dialog - base class for Games::Pandemic dialog windows
 
 =head1 VERSION
 
-version 0.6.0
+version 0.7.0
 
 =begin Pod::Coverage
 
